// Copyright (c) 2010 Volvox Development Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
//
// Author: Konstantin Lepa <konstantin.lepa@gmail.com>

#ifndef XMLPARSER_XML_VALIDATOR_BASE_HPP_
#define XMLPARSER_XML_VALIDATOR_BASE_HPP_

/**
	@file xml-validator-base.hpp
	XML validator base class
*/

#include <string>
#include <vector>

namespace simplexml
{

/**
	@addtogroup xmlgroup
	@{
	@defgroup xmlvalidgroup XML Validator
	@{
 */

class XMLElement;

/**
	Base class for validating xml.
 */
class XMLValidatorBase
{
public:
	/**
		Validate xml tree
		@param root - root of xml tree
		@throws simplexml::XMLException
	 */
	virtual void Validate(XMLElement *root) const = 0;

	virtual ~XMLValidatorBase() throw() { ;; }

}; // class XMLValidatorBase

/** @} @} */

} // namespace simplexml

#endif // XMLPARSER_XML_VALIDATOR_BASE_HPP_

