// Copyright (c) 2010 Volvox Development Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
//
// Author: Konstantin Lepa <konstantin.lepa@gmail.com>

#ifndef XMLPARSER_XML_VALUE_HPP_
#define XMLPARSER_XML_VALUE_HPP_

/**
	@file xml-value.hpp
	XML attribute value
*/

#include "xml-exception.hpp"

namespace simplexml
{

/**
	@addtogroup xmlgroup
	@{
 */

/**
	Config value
 */
class XMLValue
{

public:
	XMLValue() : value_() { ;; }

	/**
		@param val - [in] value
	 */
	XMLValue(const std::string &val) : value_(val) { ;; }

	/**
		Set new value
	 */
	XMLValue(const XMLValue &other) { value_ = other.value_; }

	/**
		Get string value
		@return string value
	 */
	const std::string & AsString() const throw();

	/**
		Get integer value
		@return integer value
		@throw XMLException
	 */
	INT_64 AsInteger() const;

	/**
		Get floating-point value
		@return floating-point value
		@throw XMLException
	 */
	W_FLOAT AsFloat() const;

	/**
		Get boolean value
		@return boolean value (true or false)
		@throw XMLException
	 */
	bool AsBool() const;

	/**
		Check existence of value
	 */
	bool Empty() const { return value_.empty(); }

	/**
		Erase value.
	 */
	void Erase() { value_.erase(); }

private:
	std::string value_;	///< Stored value

}; // class XMLValue

/** @} */

} // namespace simplexml

#endif // XMLPARSER_XML_VALUE_HPP_

